@@ -39,6 +39,7 @@ import qualified Data.ByteString.Base64.Lazy as B64L
 import qualified Data.ByteString.Base64.URL.Lazy as B64LU
 import qualified Data.ByteString.Base64.URL as B64U
 import Control.Monad.ST (runST)
+import qualified StreamSpec
 
 main :: IO ()
 main = hspec $ do
@@ -140,13 +141,13 @@ main = hspec $ do
     it "sourceDirectory" $ do
         res <- runResourceT
              $ sourceDirectory "test" $$ filterC (not . flip hasExtension "swp") =$ sinkList
-        sort res `shouldBe` ["test/Spec.hs", "test/subdir"]
+        sort res `shouldBe` ["test/Spec.hs", "test/StreamSpec.hs", "test/subdir"]
     it "sourceDirectoryDeep" $ do
         res1 <- runResourceT
               $ sourceDirectoryDeep False "test" $$ filterC (not . flip hasExtension "swp") =$ sinkList
         res2 <- runResourceT
               $ sourceDirectoryDeep True "test" $$ filterC (not . flip hasExtension "swp") =$ sinkList
-        sort res1 `shouldBe` ["test/Spec.hs", "test/subdir/dummyfile.txt"]
+        sort res1 `shouldBe` ["test/Spec.hs", "test/StreamSpec.hs", "test/subdir/dummyfile.txt"]
         sort res1 `shouldBe` sort res2
     prop "drop" $ \(T.pack -> input) count ->
         runIdentity (yieldMany input $$ (dropC count >>= \() -> sinkList))
@@ -625,6 +626,7 @@ main = hspec $ do
                   where
                     (y, z) = splitAt size x
         res `shouldBe` expected
+    StreamSpec.spec
 
 evenInt :: Int -> Bool
 evenInt = even
